@@ -5,7 +5,9 @@ use warnings;
 use base qw( Alien::Base );
 
 # ABSTRACT: Find or build xz
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
+
+
 
 
 sub alien_helper
@@ -15,6 +17,9 @@ sub alien_helper
   };
 }
 
+
+
+
 1;
 
 __END__
@@ -29,32 +34,54 @@ Alien::xz - Find or build xz
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
-From a Perl script
+In your Build.PL:
+
+ use Module::Build;
+ use Alien::xz;
+ my $builder = Module::Build->new(
+   ...
+   configure_requires => {
+     'Alien::xz' => '0',
+     ...
+   },
+   extra_compiler_flags => Alien::xz->cflags,
+   extra_linker_flags   => Alien::xz->libs,
+   ...
+ );
+ 
+ $build->create_build_script;
+
+In your Makefile.PL:
+
+ use ExtUtils::MakeMaker;
+ use Config;
+ use Alien::xz;
+ 
+ WriteMakefile(
+   ...
+   CONFIGURE_REQUIRES => {
+     'Alien::xz' => '0',
+   },
+   CCFLAGS => Alien::xz->cflags . " $Config{ccflags}",
+   LIBS    => [ Alien::xz->libs ],
+   ...
+ );
+
+In your script or module:
 
  use Alien::xz;
  use Env qw( @PATH );
- unshift @PATH, Alien::xz->bin_dir;  # xz is now in your path
-
-From Alien::Base Build.PL
-
- use Alien:Base::ModuleBuild;
- my $builder = Module::Build->new(
-   ...
-   alien_bin_requires => {
-     'Alien::xz' => '0.02',
-   }
-   ...
- );
- $builder->create_build_script;
+ 
+ unshift @ENV, Alien::xz->bin_dir;
 
 =head1 DESCRIPTION
 
 This package can be used by other CPAN modules that require xz,
-the compression utility.
+the compression utility, or liblzma, which comes with it.
 
 =head1 HELPERS
 
@@ -64,6 +91,10 @@ the compression utility.
 
 Returns the name of the xz command.  Usually just C<xz>.
 
+=head1 SEE ALSO
+
+L<Alien>, L<Alien::Base>, L<Alien::Build::Manual::AlienUser>
+
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
